@@ -78,23 +78,10 @@ class BaseCollection:
                     to_remove = list(existing_id - updated_id)
                     if len(to_add + to_remove) == 0:  # if there are no changes, skip
                         continue
-                    if len(to_add) > 0 and len(to_remove) > 0:
-                        data.append(
-                            PatchDatum(
-                                attribute=attribute,
-                                operation=PatchOperation.UPDATE,
-                                old_value=existing_id,
-                                new_value=updated_id,
-                            )
-                        )
-                    elif len(to_add) > 0:
-                        data.append(
-                            PatchDatum(
-                                attribute=attribute, operation=PatchOperation.ADD, new_value=to_add
-                            )
-                        )
 
-                    elif len(to_remove) > 0:
+                    # Handle additions and removals separately to avoid conflicts
+
+                    if len(to_remove) > 0:
                         data.append(
                             PatchDatum(
                                 attribute=attribute,
@@ -103,6 +90,12 @@ class BaseCollection:
                             )
                         )
 
+                    if len(to_add) > 0:
+                        data.append(
+                            PatchDatum(
+                                attribute=attribute, operation=PatchOperation.ADD, new_value=to_add
+                            )
+                        )
                 else:
                     data.append(
                         PatchDatum(
@@ -189,6 +182,13 @@ class BaseCollection:
                             new_value=new_value,
                         )
                     )
+                if new_value is None and old_value is not None:
+                    # Delete the attribute
+                    data.append(
+                        PatchDatum(
+                            attribute=alias, operation=PatchOperation.DELETE, old_value=old_value
+                        )
+                    )
                 elif old_value is not None and new_value != old_value:
                     # Update existing attribute
                     old_value = str(old_value) if stringify_values else old_value
