@@ -1,9 +1,12 @@
 from collections.abc import Iterator
 
+from pydantic import validate_call
+
 from albert.collections.base import BaseCollection
 from albert.core.pagination import AlbertPaginator
 from albert.core.session import AlbertSession
 from albert.core.shared.enums import PaginationMode
+from albert.core.shared.identifiers import CustomFieldId
 from albert.resources.custom_fields import CustomField, FieldType, ServiceType
 
 
@@ -65,10 +68,10 @@ class CustomFieldCollection(BaseCollection):
         "min",
         "max",
         "entity_categories",
+        "default",
         # "required",
         # "multiselect",
         # "pattern",
-        # "default",
     }
     _api_version = "v3"
 
@@ -84,7 +87,8 @@ class CustomFieldCollection(BaseCollection):
         super().__init__(session=session)
         self.base_path = f"/api/{CustomFieldCollection._api_version}/customfields"
 
-    def get_by_id(self, *, id: str) -> CustomField:
+    @validate_call
+    def get_by_id(self, *, id: CustomFieldId) -> CustomField:
         """Get a CustomField item by its ID.
 
         Parameters
@@ -233,6 +237,12 @@ class CustomFieldCollection(BaseCollection):
 
         # run patch
         url = f"{self.base_path}/{custom_field.id}"
-        self.session.patch(url, json=payload.model_dump(mode="json", by_alias=True))
+
+        self.session.patch(
+            url,
+            json=payload.model_dump(
+                mode="json", by_alias=True, exclude_unset=False, exclude_none=True
+            ),
+        )
         updated_ctf = self.get_by_id(id=custom_field.id)
         return updated_ctf
