@@ -1,9 +1,13 @@
 from collections.abc import Iterator
 
+from pydantic import validate_call
+
 from albert.collections.base import BaseCollection
 from albert.core.pagination import AlbertPaginator
 from albert.core.session import AlbertSession
 from albert.core.shared.enums import PaginationMode
+from albert.core.shared.identifiers import InventoryId, LotId
+from albert.core.shared.models.patch import PatchDatum, PatchOperation, PatchPayload
 from albert.resources.lots import Lot
 
 
@@ -46,7 +50,8 @@ class LotCollection(BaseCollection):
         # return [Lot(**lot) for lot in response.json().get("CreatedLots", [])]
         return all_lots
 
-    def get_by_id(self, *, id: str) -> Lot:
+    @validate_call
+    def get_by_id(self, *, id: LotId) -> Lot:
         """Get a lot by its ID.
 
         Parameters
@@ -63,7 +68,8 @@ class LotCollection(BaseCollection):
         response = self.session.get(url)
         return Lot(**response.json())
 
-    def get_by_ids(self, *, ids: list[str]) -> list[Lot]:
+    @validate_call
+    def get_by_ids(self, *, ids: list[LotId]) -> list[Lot]:
         """Get a list of lots by their IDs.
 
         Parameters
@@ -80,7 +86,8 @@ class LotCollection(BaseCollection):
         response = self.session.get(url, params={"id": ids})
         return [Lot(**lot) for lot in response.json()["Items"]]
 
-    def delete(self, *, id: str) -> None:
+    @validate_call
+    def delete(self, *, id: LotId) -> None:
         """Delete a lot by its ID.
 
         Parameters
@@ -91,11 +98,12 @@ class LotCollection(BaseCollection):
         url = f"{self.base_path}?id={id}"
         self.session.delete(url)
 
+    @validate_call
     def get_all(
         self,
         *,
-        parent_id: str | None = None,
-        inventory_id: str | None = None,
+        parent_id: InventoryId | None = None,
+        inventory_id: InventoryId | None = None,
         barcode_id: str | None = None,
         parent_id_category: str | None = None,
         inventory_on_hand: str | None = None,
@@ -157,6 +165,28 @@ class LotCollection(BaseCollection):
             deserialize=lambda items: [Lot(**item) for item in items],
         )
 
+    def _generate_lots_patch_payload(self, *, existing: Lot, updated: Lot) -> PatchPayload:
+        """Generate a patch payload for a lot, handling inventory_on_hand separately."""
+        patch_data = super()._generate_patch_payload(
+            existing=existing, updated=updated, generate_metadata_diff=False
+        )
+        # inventory on hand is a special case, where the API expects a delta
+        if (
+            updated.inventory_on_hand is not None
+            and updated.inventory_on_hand != existing.inventory_on_hand
+        ):
+            patch_data.data = [d for d in patch_data.data if d.attribute != "inventoryOnHand"]
+            delta = updated.inventory_on_hand - existing.inventory_on_hand
+            patch_data.data.append(
+                PatchDatum(
+                    attribute="inventoryOnHand",
+                    operation=PatchOperation.UPDATE,
+                    new_value=str(delta),
+                    old_value=str(existing.inventory_on_hand),
+                )
+            )
+        return patch_data
+
     def update(self, *, lot: Lot) -> Lot:
         """Update a lot.
 
@@ -171,9 +201,9 @@ class LotCollection(BaseCollection):
             The updated Lot entity as returned by the server.
         """
         existing_lot = self.get_by_id(id=lot.id)
-        patch_data = self._generate_patch_payload(existing=existing_lot, updated=lot)
+        patch_data = self._generate_lots_patch_payload(existing=existing_lot, updated=lot)
         url = f"{self.base_path}/{lot.id}"
-
-        self.session.patch(url, json=patch_data.model_dump(mode="json", by_alias=True))
+        if patch_data.data:
+            self.session.patch(url, json=patch_data.model_dump(mode="json", by_alias=True))
 
         return self.get_by_id(id=lot.id)
