@@ -63,7 +63,7 @@ class Interval(BaseAlbertModel):
     def validate_interval(self) -> "Interval":
         if not self.value:
             raise ValueError("Interval: 'value' is required.")
-        if not self.unit or not getattr(self.unit, "id", None):
+        if self.unit and not getattr(self.unit, "id", None):
             raise ValueError("Interval: 'Unit.id' is required.")
         return self
 
@@ -171,7 +171,7 @@ class ParameterSetpoint(BaseAlbertModel):
 
         # Normal Parameters
         # Exactly one of value / intervals
-        if (self.value is None) == (self.intervals is None):
+        if self.value is not None and self.intervals is not None:
             raise ValueError(f"Parameter {pid}: provide exactly one of 'value' or 'Intervals'.")
 
         # If value is mapping-shaped for Normal, it must include id (e.g., enum {id,...})
