@@ -73,7 +73,6 @@ def client() -> Albert:
         base_url_env="ALBERT_BASE_URL",
     )
     return Albert(
-        base_url="https://app.albertinvent.com",
         auth_manager=credentials,
         retries=3,
     )
@@ -374,7 +373,7 @@ def seeded_worksheet(client: Albert, seeded_projects: list[Project]) -> Workshee
         wksht = collection.get_by_project_id(project_id=seeded_projects[0].id)
     except NotFoundError:
         wksht = collection.setup_worksheet(project_id=seeded_projects[0].id)
-    if wksht.sheets is None or wksht.sheets == []:
+    if not wksht.sheets:
         wksht = collection.add_sheet(project_id=seeded_projects[0].id, sheet_name="test")
     else:
         for s in wksht.sheets:
